@@ -9,7 +9,10 @@ See: main driver
 
 """
 
-__version__ = "3.01.15"
+__version__ = "3.20.00"
+
+import yaml
+
 temp_created_project = "temp_created_project"   # see copy_if_mounted
 
 import socket
@@ -62,7 +65,17 @@ from create_from_model.model_creation_services import CreateFromModel
 import expose_existing.expose_existing_callable as expose_existing_callable
 import create_from_model.api_logic_server_utils as create_utils
 
+
+api_logic_server_info_file_name = get_api_logic_server_dir() + "/api_logic_server_info.yaml"
+api_logic_server_info_file = open(api_logic_server_info_file_name)
+api_logic_server_info_file_dict = yaml.load(api_logic_server_info_file, Loader=yaml.FullLoader)
+api_logic_server_info_file.close()
+
+last_created_project_name = api_logic_server_info_file_dict["last_created_project_name"]
 default_db = "<default -- nw.sqlite>"
+default_project_name = "api_logic_server"
+if os.path.exists('/home/api_logic_server'):  # docker?
+    default_project_name = "/localhost/api_logic_server"
 
 #  MetaData = NewType('MetaData', object)
 MetaDataTable = NewType('MetaDataTable', object)
@@ -314,7 +327,8 @@ def update_api_logic_server_run(project_name, project_directory, host, port):
                            replace_with='"' + os.path.basename(project_name) + '"',
                            in_file=api_logic_server_run_py)
     create_utils.replace_string_in_file(search_for="ApiLogicServer hello",
-                           replace_with="ApiLogicServer generated at:" + str(datetime.datetime.now()),
+                           replace_with="ApiLogicServer generated at:" +
+                                        str(datetime.datetime.now().strftime("%B %d, %Y %H:%M:%S")),
                            in_file=api_logic_server_run_py)
     project_directory_fix = project_directory_actual
     if os.name == "nt":  # windows
@@ -656,6 +670,12 @@ def api_logic_server(project_name: str, db_url: str, host: str, port: str, not_e
             copy_project_to_local(project_directory, copy_to_project_directory,
                                   f'10. Copy temp_created_project over {copy_to_project_directory} ')
 
+    api_logic_server_info_file_dict["last_created_project_name"] = project_directory  # project_name - twiddle
+    api_logic_server_info_file_dict["last_created_date"] = str(datetime.datetime.now().strftime("%B %d, %Y %H:%M:%S"))
+    api_logic_server_info_file_dict["last_created_version"] = __version__
+    with open(api_logic_server_info_file_name, 'w') as api_logic_server_info_file_file:
+        yaml.dump(api_logic_server_info_file_dict, api_logic_server_info_file_file, default_flow_style=False)
+
     if run:  # synchronous run of server - does not return
         # run_file = os.path.abspath(f'{project_directory}/api_logic_server_run.py')
         # create_utils.run_command(f'python {run_file} {host}', msg="\nRun created ApiLogicServer project")
@@ -682,40 +702,39 @@ def main(ctx):
     """
     Creates and runs logic-enabled Python project.
 
-        Examples:
+    Example:
 
-            ApiLogicServer run  # use defaults (verify install)
+        ApiLogicServer create-and-run --project_name= --db_url=
 
-            ApiLogicServer run --db_url=sqlite:///nw.sqlite
+    Doc:
 
-        Doc:
+        ApiLogicServer: https://github.com/valhuber/ApiLogicServer#readme
 
-            ApiLogicServer: https://github.com/valhuber/ApiLogicServer#readme
+        Logic Bank: https://github.com/valhuber/logicbank#readme
 
-            Logic Bank: https://github.com/valhuber/logicbank#readme
+        SQLAlchemy: https://docs.sqlalchemy.org/en/14/core/engines.html
 
-            SQLAlchemy: https://docs.sqlalchemy.org/en/14/core/engines.html
+        SAFRS: https://github.com/thomaxxl/safrs/wiki
 
-            SAFRS: https://github.com/thomaxxl/safrs/wiki
+        FAB: https://flask-appbuilder.readthedocs.io/en/latest/
 
-            FAB: https://flask-appbuilder.readthedocs.io/en/latest/
-
-    https://github.com/valhuber/ApiLogicServer/wiki/Tutorial
+        https://github.com/valhuber/ApiLogicServer/wiki/Tutorial
     """
 
-
 @main.command("version")
 @click.pass_context
 def version(ctx):
     """
         Recent Changes
     """
-    print_info()
+    # print_info()
     print(f'\tInstalled at {abspath(__file__)}\n')
     print(f'\thttps://github.com/valhuber/ApiLogicServer/wiki/Tutorial\n')
     click.echo(
         click.style(
             f'Recent Changes:\n'
+            "\t10/02/2021 - 03.20.00: bugfix missing SQLAlchemy-utils, default run project_name to last created \n"
+            "\t10/02/2021 - 03.10.17: bugfix improper run arg for VSCode launch configuration, default db_url \n"
             "\t09/29/2021 - 03.01.15: run (now just runs without create), added create-and-run \n"
             "\t09/25/2021 - 03.01.10: run command for Docker, pyodbc, fab create-by-copy, localhost swagger \n"
             "\t09/15/2021 - 03.00.09: auto-create .devcontainer for vscode, configure network, python & debug \n"
@@ -732,7 +751,8 @@ def version(ctx):
               prompt="SQLAlchemy Database URI",
               help="SQLAlchemy Database URL - see above\n")
 @click.option('--project_name',
-              default="api_logic_server",
+              default=f'{default_project_name}',
+              prompt="Project to create",
               help="Create new directory here")
 @click.option('--from_git',
               default="",
@@ -786,9 +806,9 @@ def create(ctx, project_name: str, db_url: str, not_exposed: str,
     """
         Creates new project (overwrites)
     """
-    print_info()
+    # print_info()
     db_types = ""
-    if db_url == default_db:
+    if db_url == default_db or db_url == "":
         db_url = f'sqlite:///{abspath(get_api_logic_server_dir())}/project_prototype_nw/nw.sqlite'
     api_logic_server(project_name=project_name, db_url=db_url,
                      not_exposed=not_exposed,
@@ -805,7 +825,8 @@ def create(ctx, project_name: str, db_url: str, not_exposed: str,
               prompt="SQLAlchemy Database URI",
               help="SQLAlchemy Database URL - see above\n")
 @click.option('--project_name',
-              default="api_logic_server",
+              default=f'{default_project_name}',
+              prompt="Project to create and run",
               help="Create new directory here")
 @click.option('--from_git',
               default="",
@@ -859,9 +880,9 @@ def create_and_run(ctx, project_name: str, db_url: str, not_exposed: str,
     """
         Creates new project and runs it (overwrites)
     """
-    print_info()
+    # print_info()
     db_types = ""
-    if db_url == default_db:
+    if db_url == default_db or db_url == "":
         db_url = f'sqlite:///{abspath(get_api_logic_server_dir())}/project_prototype_nw/nw.sqlite'
     api_logic_server(project_name=project_name, db_url=db_url,
                      not_exposed=not_exposed,
@@ -874,7 +895,8 @@ def create_and_run(ctx, project_name: str, db_url: str, not_exposed: str,
 
 @main.command("run")
 @click.option('--project_name',
-              default="api_logic_server",
+              default=f'{last_created_project_name}',
+              prompt="Project to run",
               help="Project to run")
 @click.option('--host',
               default=f'localhost',
@@ -883,7 +905,7 @@ def create_and_run(ctx, project_name: str, db_url: str, not_exposed: str,
               default=f'5000',
               help="Port (default 5000, or leave empty)")
 @click.pass_context
-def run(ctx, project_name: str, host: str="localhost", port: str="5000"):
+def run_api(ctx, project_name: str, host: str="localhost", port: str="5000"):
     """
         Runs existing project
     """
@@ -894,6 +916,99 @@ def run(ctx, project_name: str, host: str="localhost", port: str="5000"):
     create_utils.run_command(f'python {run_file}', msg="Run created ApiLogicServer project", new_line=True)
 
 
+@main.command("run-ui")
+@click.option('--project_name',
+              default=f'{last_created_project_name}',
+              prompt="Project to run",
+              help="Project to run")
+@click.option('--host',
+              default=f'localhost',
+              help="Server hostname (default is localhost)")
+@click.option('--port',
+              default=f'5000',
+              help="Port (default 5000, or leave empty)")
+@click.pass_context
+def run_ui(ctx, project_name: str, host: str="localhost", port: str="5000"):
+    """
+        Runs existing basic web app
+    """
+
+    # run_file = os.path.abspath(f'{project_directory}/api_logic_server_run.py')
+    # create_utils.run_command(f'python {run_file} {host}', msg="\nRun created ApiLogicServer project")
+    run_file = os.path.abspath(f'{resolve_home(project_name)}/ui/basic_web_app/run.py {host} 8080')
+    create_utils.run_command(f'python {run_file}', msg="Run created ApiLogicServer Basic Web App", new_line=True)
+
+
+@main.command("sys-info")
+@click.pass_context
+def sys_info(ctx):
+    """
+        Python version, paths, IPs, etc
+    """
+
+    def print_at(label: str, value: str):
+        tab_to = 24 - len(label)
+        spaces = ' ' * tab_to
+        print(f'{label}: {spaces}{value}')
+
+    print("\nPYTHONPATH..")
+    for p in sys.path:
+        print(".." + p)
+    print("")
+    hostname = socket.gethostname()
+    local_ip = socket.gethostbyname(hostname)
+    print_at('ApiLogicServer version', __version__)
+    print_at('ip (gethostbyname)', local_ip)
+    print_at('on hostname', hostname)
+    print_at("Python version", create_utils.run_command(f'python --version', msg="no-msg"))
+
+
+@main.command("welcome")
+@click.pass_context
+def welcome(ctx):
+    """
+        Show version, typical commands
+    """
+    print("")
+    print("Typical commands:")
+    print("  ApiLogicServer create-and-run --project_name=/localhost/api_logic_server --db_url=")
+    print("  ApiLogicServer run            --project_name=/localhost/api_logic_server")
+    print("  ApiLogicServer run-ui         --project_name=/localhost/api_logic_server   # login: admin, p")
+    print("  ApiLogicServer sys-info")
+    print("  ApiLogicServer version")
+    print("")
+
+
+@main.command("examples")
+@click.pass_context
+def examples(ctx):
+    """
+    Example commands, including SQLAlchemy URIs
+
+    URI examples, Docs URL
+    """
+    info = [
+        'Examples:',
+        '  ApiLogicServer create-and-run',
+        '  ApiLogicServer create-and-run --db_url=sqlite:///nw.sqlite',
+        '  ApiLogicServer create-and-run --db_url=mysql+pymysql://root:p@mysql-container:3306/classicmodels '
+        '--project_name=/localhost/docker_db_project',
+        '  ApiLogicServer create-and-run --db_url=mssql+pyodbc://sa:posey386!@localhost:1433/NORTHWND?'
+        'driver=ODBC+Driver+17+for+SQL+Server?trusted_connection=no',
+        '  ApiLogicServer create-and-run --db_url=postgresql://postgres:p@10.0.0.234/postgres',
+        '  ApiLogicServer create-and-run --db_url=postgresql+psycopg2:'
+        '//postgres:password@localhost:5432/postgres?options=-csearch_path%3Dmy_db_schema',
+        '  ApiLogicServer create --host=ApiLogicServer.pythonanywhere.com --port=',
+        '',
+        'Where --db_url defaults to supplied sample, or, specify URI for your own database:',
+        '   SQLAlchemy Database URI help: https://docs.sqlalchemy.org/en/14/core/engines.html',
+        '   Other URI examples:           https://github.com/valhuber/ApiLogicServer/wiki/Testing',
+        ' ',
+        'Docs: https://github.com/valhuber/ApiLogicServer#readme\n'
+    ]
+    for each_line in info:
+        print(each_line)
+
 log = logging.getLogger(__name__)
 
 
@@ -911,7 +1026,7 @@ def print_info():
         '  ApiLogicServer create-and-run',
         '  ApiLogicServer create-and-run --db_url=sqlite:///nw.sqlite',
         '  ApiLogicServer create-and-run --db_url=mysql+pymysql://root:p@mysql-container:3306/classicmodels '
-        '--project_name=/local/servers/docker_db_project',
+        '--project_name=/localhost/docker_db_project',
         '  ApiLogicServer create-and-run --db_url=mssql+pyodbc://sa:posey386!@localhost:1433/NORTHWND?'
         'driver=ODBC+Driver+17+for+SQL+Server?trusted_connection=no',
         '  ApiLogicServer create-and-run --db_url=postgresql://postgres:p@10.0.0.234/postgres',
@@ -938,6 +1053,8 @@ def print_args(args, msg):
 
 
 def start():               # target of setup.py
+    hostname = socket.gethostname()
+    local_ip = socket.gethostbyname(hostname)
     sys.stdout.write("\nWelcome to API Logic Server " + __version__ + "\n")
     # sys.stdout.write("    SQLAlchemy Database URI help: https://docs.sqlalchemy.org/en/14/core/engines.html\n")
     # sys.stdout.write("    Other examples are at:        https://github.com/valhuber/ApiLogicServer/wiki/Testing\n\n")
@@ -950,8 +1067,9 @@ if __name__ == '__main__':  # debugger & python command line start here
 
     hostname = socket.gethostname()
     local_ip = socket.gethostbyname(hostname)
-    print(f'\nWelcome to API Logic Server, {__version__} at {local_ip} ')
+    print(f'\nWelcome to API Logic Server, {__version__}')  #  at {local_ip} ')
     commands = sys.argv
-    if len(sys.argv) > 1 and sys.argv[1] != "version":
+    if len(sys.argv) > 1 and sys.argv[1] not in ["version", "sys-info", "welcome"] and \
+            "show-args" in api_logic_server_info_file_dict:
         print_args(commands, f'\nCommand Line Arguments:')
     main()
\ No newline at end of file
